import 'package:flutter/material.dart';

class CategoryForm extends StatelessWidget {
  final GlobalKey<FormState> _formKey = GlobalKey<FormState>();
  final TextEditingController _claveController = TextEditingController();
  final TextEditingController _fechaCreadoController = TextEditingController();
  final TextEditingController _nombreController = TextEditingController();

  // Función para obtener la fecha en milisegundos
  int _getFechaCreadoEnMilisegundos(String fecha) {
    try {
      // convertimos el String a DateTime y luego obtenemos el tiempo en milisegundos
      DateTime fechaCreado = DateTime.parse(fecha);
      return fechaCreado.millisecondsSinceEpoch;
    } catch (e) {
      // Si hay un error en la conversión, devolvemos 0
      return 0;
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Agregar Categoría'),
        backgroundColor: Colors.red
      ),
      body: Padding(
        padding: const EdgeInsets.all(16.0),
        child: Form(
          key: _formKey,
          child: Column(
            children: [
              TextFormField(
                controller: _claveController,
                decoration: InputDecoration(labelText: 'Clave',
                    border: OutlineInputBorder()
                  ),
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Por favor ingrese la clave';
                  }
                  return null;
                },
              ),
              SizedBox(height: 20),

              TextFormField(
                controller: _fechaCreadoController,
                decoration: InputDecoration(
                    labelText: 'Fecha Creado (YYYY-MM-DD)',
                    border: OutlineInputBorder()),
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Por favor ingrese la fecha en formato YYYY-MM-DD';
                  }
                  // Validación de la fecha
                  try {
                    DateTime.parse(value);
                  } catch (e) {
                    return 'Por favor ingrese una fecha válida';
                  }
                  return null;
                },
              ),
              SizedBox(height: 20),

              TextFormField(
                //padding: const EdgeInsets.symmetric(horizontal: 80.0), // añado mi margen horizontal
                controller: _nombreController,
                decoration: InputDecoration(
                    labelText: 'Nombre',
                    border: OutlineInputBorder(),
              ),
                validator: (value) {
                  if (value == null || value.isEmpty) {
                    return 'Por favor ingrese el nombre';
                  }
                  return null;
                },
              ),
              SizedBox(height: 20),
              ElevatedButton(
                onPressed: () {
                  if (_formKey.currentState!.validate()) {
                    // Guardar los valores y mostrar mensaje en consola
                    print({
                      "clave": _claveController.text,
                      "fechaCreado": _getFechaCreadoEnMilisegundos(_fechaCreadoController.text),
                      "nombre": _nombreController.text,
                    });
                  }
                },
                child: Text('GUARDAR'),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
